###########################################################################
#
#   Copyright (c) 2000 Morten W. Petersen <morten@esol.no>
#	Copyright (c) 2000 Thingamy Ltd.
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
#    MA 02111-1307 USA
#
#
###########################################################################

# $Author: morten $
# $Revision: 1.7 $


__doc__ = 'Documentation string.'
__version__ = '0.1.0'

from Globals import HTMLFile
from Globals import Persistent
from Globals import default__class_init__
import Acquisition
import AccessControl.Role
import OFS.SimpleItem
import Products
import base_item
import re
import string

add_message_filter_redirect = HTMLFile('message_filter_add_redirect', globals())
manage_add_message_filter_form = HTMLFile('message_filter_add', globals())


def manage_add_message_filter(self, id, title, header_name='', regexp_rule='',
				message_container='', REQUEST=None, RESPONSE=None):
	"Add an instance of the message_filter class"

	self._setObject(id,
			message_filter(id, title, header_name, regexp_rule,
			message_container))

	if RESPONSE is not None:

	        RESPONSE.redirect(self.absolute_url())


class message_filter(
	Products.ZCatalog.CatalogAwareness.CatalogAware,
	Persistent,
	Acquisition.Implicit,
	OFS.SimpleItem.SimpleItem,
	AccessControl.Role.RoleManager,
	base_item.base_item
	):
	"Documentation string"

	meta_type = 'MessageFilter'
	icon = 'misc_/GUM/dtmldoc.gif'
	#default_catalog = 'Catalog'

	header_names = ('from', 'to', 'cc', 'any')

	_properties = (
		{'id':'title', 'type':'string'},
		{'id':'header_name', 'type':'string'},
		{'id':'regexp_rule', 'type':'string'},
		{'id':'message_container', 'type':'string'},
		{'id':'match_any_header', 'type':'string'}
		)


	__ac_permissions__ = (
		('View management screens',
		 ('manage_tabs', 'manage_main')),
		('Change Permissions',
		 ('manage_access',)),
		('View MessageFilter',
		 ('',)),
		)

	index_html = HTMLFile('message_filter_index', globals())

	base_edit = HTMLFile('message_filter_edit', globals())

	def base_edit_properties(self, title, header_name, regexp_rule,
					message_container, RESPONSE):
		"""Updates self.."""

		self.title = title
		self.header_name = header_name
		self.regexp_rule = regexp_rule
		self.message_container = message_container

		if header_name == 'any':

			self.match_any_header = 1

		self.link()

		RESPONSE.redirect(self.absolute_url())


	def __init__(self, id, title, header_name, regexp_rule,
			message_container):
		"Initialize the class instance"

		self.id = id
		self.title = title

		self.header_name = header_name

		if header_name =='any':

			self.match_any_header = 1

		else:

			self.match_any_header = 0

		self.regexp_rule = regexp_rule
		self.message_container = message_container

		self.link()

		#self.index_object()


	def link(self):
		"""Compiles the regexp_rule."""

		self._regexp_rule = re.compile(re.escape(
						string.strip(self.regexp_rule)))


	def match(self, headers):
		"""Returns a truth value if header contains what we're
		looking for."""

		if self.match_any_header:

			for header_value in headers.values():

				match_object = self._regexp_rule.search(header_value)

				if match_object:

					print 'matched %s with %s' % (self.id,
									header_value)

					return match_object

			else:

				#print "%s couldn't match any header" % self.id
				#print "title: %s" % self.title
				#print "regexp_rule: %s" % self.regexp_rule
				#print "headers: %s" % headers

				print 'title:', self.title

				return None

		else:

			match_object = self._regexp_rule.search(
						headers[self.header_name])

		if match_object is not None:

			print match_object.group()

			return match_object

		else:

			print 'match object was %s' % match_object

			print 'value %s did not match' % self.regexp_rule
			print 'value of header is %s' % headers[self.header_name]

			return match_object


default__class_init__(message_filter)
